#! /usr/bin/env python
import random

from irc import IRCBot, run_bot
from core import scrib


# Identify yourself and send default settings
scrib = scrib.scrib('irc', {
	'host': 'irc.thescoundrels.net',
	'debug': 0,
	'port': 6667,
	'nick': scrib.cfg.get_name(),
	'quitmsg': 'Goodbye!',
	'chans': ['#scoundrels'],
	'chatrate': 0.05,
	'maxwords': 30
})
settings = scrib.setcfg()


class ScribIRC(IRCBot):

	def __init__(self, *args, **kwargs):
		super(ScribIRC, self).__init__(*args, **kwargs)

	def log(self, sender, message, channel):
		if message.startswith('/'):
			if scrib.interface.debug is 1:
				scrib.barf('DBG', '%s' % (message))
			return

		scrib.barf('MSG', '%s: <%s> \033[0m%s' % (
			channel,
			sender,
			message
		))
		reply = self.is_ping(message) or (
			sender != self.conn.nick and random.random() < scrib.interface.chatrate
		)

		if self.is_ping(message):
			message = self.fix_ping(message)

		if message is not None:
			self.respond(scrib.reply(message, reply), channel)

	def greet(self, sender, message, channel):
		self.respond(scrib.reply('hello ' + channel, learn=False), channel)

	def part(self, sender, message, channel):
		self.respond(scrib.reply(scrib.interface.quitmsg, learn=False), channel)

	def quit(self, sender, message, channel):
		self.part(sender, message, channel)
		scrib.shutdown()

	def command_patterns(self):
		return (
			('.*', self.log),
			('/join', self.greet),
			('/part', self.log),
			('!quit', self.quit),
		)

if __name__ == "__main__":
	try:
		run_bot(
			ScribIRC,
			scrib.interface.host,
			scrib.interface.port,
			scrib.interface.nick,
			scrib.interface.chans
		)
	except KeyboardInterrupt:
		pass
	scrib.shutdown()
